@@ -1,4 +1,4 @@
-# Copyright 2007-2011, Paul Johnson (pjcj@cpan.org)
+# Copyright 2007-2013, Paul Johnson (paul@pjcj.net)
 # except where otherwise noted.
 
 # This software is free.  It is licensed under the same terms as Perl itself,
@@ -12,7 +12,7 @@ package Devel::Cover::Web;
 use strict;
 use warnings;
 
-our $VERSION = "0.78";
+our $VERSION = '1.00'; # VERSION
 
 use Exporter;
 
@@ -97,6 +97,7 @@ th,.h,.hh,.sh,.sv {
 }
 
 .sv {
+    width       : 0;
     padding     : 0.2em;
 }
 
@@ -903,6 +904,10 @@ EOF
 
 Devel::Cover::Web - Files for JavaScript or CSS
 
+=head1 VERSION
+
+version 1.00
+
 =head1 SYNOPSIS
 
  use Devel::Cover::Web "write_file";
@@ -932,13 +937,9 @@ Output the specified file to the specified directory.
 
 Huh?
 
-=head1 VERSION
-
-Version 0.78 - 17th May 2011
-
 =head1 LICENCE
 
-Copyright 2007-2011, Paul Johnson (pjcj@cpan.org) except where otherwise noted.
+Copyright 2007-2013, Paul Johnson (paul@pjcj.net) except where otherwise noted.
 
 This software is free.  It is licensed under the same terms as Perl itself,
 except where otherwise noted.
